AnimationConfiguration class

Provides animation config (position, duration, delay, columnCount) to descendant AnimationConfigurator widgets via InheritedWidget.

Inheritance

Constructors

AnimationConfiguration.staggeredGrid({Key? key, required int position, Duration duration = const Duration(milliseconds: 225), Duration? delay, required int columnCount, required Widget child})
Children animate with staggered delays based on grid position.
const
AnimationConfiguration.staggeredList({Key? key, required int position, Duration duration = const Duration(milliseconds: 225), Duration? delay, required Widget child})
Children animate with staggered delays based on list position.
const
AnimationConfiguration.synchronized({Key? key, Duration duration = const Duration(milliseconds: 225), required Widget child})
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
columnCount int
final
delay Duration?
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
position int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) AnimationConfiguration?
toStaggeredList({Duration duration = const Duration(milliseconds: 225), Duration? delay, required Widget childAnimationBuilder(Widget), required List<Widget> children}) List<Widget>
Wraps each widget in children with a staggeredList configuration.