CustomButtons class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
customOutlinedButton({required String title, required Color lineColor, required VoidCallback onPressed, Color? textColor})
→ Widget
-
-
customSignInButton({required String title, required Color buttonColor, required VoidCallback onPressed, Color fontColor = Colors.white, double fontSize = 24.0, IconData icon = Icons.mail, FaIconData? faIcon})
→ Widget
-
-
customTextButton({required String title, required Color bgColor, required VoidCallback onPressed, bool isIconButton = false, IconData icon = Icons.check_circle, Color textColor = Colors.white})
→ Widget
-